from pkgutil import extend_path

# noinspection PyUnboundLocalVariable
__path__ = extend_path(__path__, __name__)
